@@ -1,7 +1,7 @@
 # Copyright © 2021 Chris Hughes
 import math
 import os
-from collections import Callable
+
 from enum import Enum
 from functools import partial
 from typing import Iterable
@@ -402,7 +402,7 @@ class Trainer:
         max_num_train_steps=None,
         gradient_accumulation_steps=1,
         gradient_clip_value=None,
-        create_scheduler_fn: Callable = None,
+        create_scheduler_fn=None,
         train_dataloader_kwargs: dict = None,
         eval_dataloader_kwargs: dict = None,
         reset_run_history=True,
@@ -668,12 +668,12 @@ class Trainer:
                 self._run_train_epoch(self._train_dataloader)
                 if self.eval_dataset is not None:
                     self._run_eval_epoch(self._eval_dataloader)
-                self.run_history._increment_epoch()
                 self.training_run_epoch_end()
                 self.callback_handler.call_event(
                     "on_training_run_epoch_end",
                     self,
                 )
+                self.run_history._increment_epoch()
             except StopTrainingError as e:
                 self._accelerator.print(e)
                 self.callback_handler.call_event(
